@@ -1,5 +1,6 @@
 import functools
 from .proptypes import PropTypes
+from .enum import Enum
 
 
 class Prop:
@@ -71,9 +72,12 @@ class Prop:
         if spec == 'Thing' and cb_type is None:
             spec, kwargs['watch'] = 'thing', True
 
-        self.vconv = self.get_conv(
-            spec, is_nillable, **kwargs
-            if spec == 'any' or spec == 'thing' else {})
+        if spec == 'Enum' and cb_type is None:
+            self.vconv = self.get_conv('enum', collection=collection)
+        else:
+            self.vconv = self.get_conv(
+                spec, is_nillable, **kwargs
+                if spec == 'any' or spec == 'thing' else {})
 
         if self.vconv is None:
             assert callable(cb_type), \
@@ -83,6 +87,10 @@ class Prop:
                 if isinstance(cb_type, type) and issubclass(cb_type, Thing) \
                 else cb_type()
 
+            if isinstance(self.model, Enum):
+                self.vconv = self.get_conv('enum', collection=collection)
+                return
+
             name = self.model._type_name
 
             assert spec == name, \
